==> openflowplugin-extension-nicira-0.8.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/group/input/updated/group/buckets/bucket/action/action/NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.group.input.updated.group.buckets.bucket.action.action;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.NxRegMove;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder} instances.
 *
 * @see NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder
 *
 */
public class NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder implements Builder<NxActionRegMoveRpcUpdateGroupUpdatedCase> {

    private NxRegMove _nxRegMove;


    Map<Class<? extends Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>>, Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>> augmentation = Collections.emptyMap();

    public NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder() {
    }
    public NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping arg) {
        this._nxRegMove = arg.getNxRegMove();
    }

    public NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder(NxActionRegMoveRpcUpdateGroupUpdatedCase base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>>, Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>> aug =((AugmentationHolder<NxActionRegMoveRpcUpdateGroupUpdatedCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nxRegMove = base.getNxRegMove();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping) {
            this._nxRegMove = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping)arg).getNxRegMove();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping]");
    }

    public NxRegMove getNxRegMove() {
        return _nxRegMove;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder setNxRegMove(final NxRegMove value) {
        this._nxRegMove = value;
        return this;
    }
    
    public NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>> augmentationType, Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionRegMoveRpcUpdateGroupUpdatedCase build() {
        return new NxActionRegMoveRpcUpdateGroupUpdatedCaseImpl(this);
    }

    private static final class NxActionRegMoveRpcUpdateGroupUpdatedCaseImpl
        extends AbstractAugmentable<NxActionRegMoveRpcUpdateGroupUpdatedCase>
        implements NxActionRegMoveRpcUpdateGroupUpdatedCase {
    
        private final NxRegMove _nxRegMove;
    
        NxActionRegMoveRpcUpdateGroupUpdatedCaseImpl(NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder base) {
            super(base.augmentation);
            this._nxRegMove = base.getNxRegMove();
        }
    
        @Override
        public Class<NxActionRegMoveRpcUpdateGroupUpdatedCase> getImplementedInterface() {
            return NxActionRegMoveRpcUpdateGroupUpdatedCase.class;
        }
    
        @Override
        public NxRegMove getNxRegMove() {
            return _nxRegMove;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxRegMove);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionRegMoveRpcUpdateGroupUpdatedCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxActionRegMoveRpcUpdateGroupUpdatedCase other = (NxActionRegMoveRpcUpdateGroupUpdatedCase)obj;
            if (!Objects.equals(_nxRegMove, other.getNxRegMove())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionRegMoveRpcUpdateGroupUpdatedCaseImpl otherImpl = (NxActionRegMoveRpcUpdateGroupUpdatedCaseImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>>, Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionRegMoveRpcUpdateGroupUpdatedCase");
            CodeHelpers.appendValue(helper, "_nxRegMove", _nxRegMove);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/group/input/updated/group/buckets/bucket/action/action/NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.group.input.updated.group.buckets.bucket.action.action;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.NxRegMove;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder
 * @see Builder
 *
 */
public class NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder implements Builder<NxActionRegMoveRpcUpdateGroupUpdatedCase> {

    private NxRegMove _nxRegMove;


    Map<Class<? extends Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>>, Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>> augmentation = Collections.emptyMap();

    public NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder() {
    }
    public NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping arg) {
        this._nxRegMove = arg.getNxRegMove();
    }

    public NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder(NxActionRegMoveRpcUpdateGroupUpdatedCase base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>>, Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>> aug =((AugmentationHolder<NxActionRegMoveRpcUpdateGroupUpdatedCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nxRegMove = base.getNxRegMove();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping) {
            this._nxRegMove = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping)arg).getNxRegMove();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping]");
    }

    public NxRegMove getNxRegMove() {
        return _nxRegMove;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder setNxRegMove(final NxRegMove value) {
        this._nxRegMove = value;
        return this;
    }
    
    public NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>> augmentationType, Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionRegMoveRpcUpdateGroupUpdatedCase build() {
        return new NxActionRegMoveRpcUpdateGroupUpdatedCaseImpl(this);
    }

    private static final class NxActionRegMoveRpcUpdateGroupUpdatedCaseImpl
        extends AbstractAugmentable<NxActionRegMoveRpcUpdateGroupUpdatedCase>
        implements NxActionRegMoveRpcUpdateGroupUpdatedCase {
    
        private final NxRegMove _nxRegMove;
    
        NxActionRegMoveRpcUpdateGroupUpdatedCaseImpl(NxActionRegMoveRpcUpdateGroupUpdatedCaseBuilder base) {
            super(base.augmentation);
            this._nxRegMove = base.getNxRegMove();
        }
    
        @Override
        public Class<NxActionRegMoveRpcUpdateGroupUpdatedCase> getImplementedInterface() {
            return NxActionRegMoveRpcUpdateGroupUpdatedCase.class;
        }
    
        @Override
        public NxRegMove getNxRegMove() {
            return _nxRegMove;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxRegMove);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionRegMoveRpcUpdateGroupUpdatedCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxActionRegMoveRpcUpdateGroupUpdatedCase other = (NxActionRegMoveRpcUpdateGroupUpdatedCase)obj;
            if (!Objects.equals(_nxRegMove, other.getNxRegMove())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionRegMoveRpcUpdateGroupUpdatedCaseImpl otherImpl = (NxActionRegMoveRpcUpdateGroupUpdatedCaseImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>>, Augmentation<NxActionRegMoveRpcUpdateGroupUpdatedCase>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionRegMoveRpcUpdateGroupUpdatedCase");
            CodeHelpers.appendValue(helper, "_nxRegMove", _nxRegMove);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
